package Daje::Workflow::Activities::Closed;
use Mojo::Base 'Daje::Workflow::Common::Activity::Base', -base, -signatures;
use v5.40;


sub closed($self) {

    $self->error->add_error("This workflow is closed");
}
1;






#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME

Daje::Workflow::Activities::Closed


=head1 DESCRIPTION

pod generated by Pod::Autopod - keep this line to make pod updates possible ####################


=head1 REQUIRES

L<v5.40> 

L<Mojo::Base> 


=head1 METHODS

=head2 closed($self)

 closed($self)();


=cut

