package Daje::Workflow::Common::Activity::Base;
use Mojo::Base -base, -signatures;

# NAME
# ====
#
# Daje::Workflow::Common::Activity::Base - Base class for activities
#
#
# DESCRIPTION
# ===========
#
#
# REQUIRES
# ========
#
# Mojo::Base
#
#
# METHODS
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#

has 'db';
has 'context';
has 'error';
has 'activity_data';
has 'model';
has 'history';

1;








#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


Daje::Workflow::Common::Activity::Base - Base class for activities




=head1 DESCRIPTION





=head1 REQUIRES


Mojo::Base


METHODS




=head1 METHODS


=head1 AUTHOR

janeskil1525 E<lt>janeskil1525@gmail.comE<gt>



=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

